@@ -92,6 +92,15 @@ class Ag:
     def bw_aktie(self) -> float:
         return round(self.buchwert / self.aktienanzahl, 2)
 
+    @property
+    def kurs_14d_live(self) -> float:
+        try:
+            return float(
+                re.compile("-?(?:\d{,3}[.])*\d{,3}[,]\d{2}|n/a").findall(self._web_data().find("div", attrs={"id": "kurs14d"}).text)[0]
+                .replace(".", "").replace(",", "."))
+        except ValueError:
+            return None
+
     @property
     def kgv(self) -> float:
         return float(re.compile("\d*[,]\d*").findall(self._web_data().find("div", attrs={"id": "kgv"}).text)[0].
@@ -243,7 +252,7 @@ class Ag:
         aktionaere = []
         for ag in self._api_data().get("ags").values():
             for aktie in ag.get("aktien"):
-                if self.wkn in aktie.values():
+                if self.wkn == aktie.get("wkn"):
                     aktionaere.append(Aktionaer(wkn=ag.get("wkn"), stueckzahl=aktie.get("stueckzahl")))
 
         return aktionaere
